==> datadog-api-client-2.2.0-sources.jar: com/datadog/api/client/v1/model/NotebookAbsoluteTime.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.datadog.api.client.JsonTimeSerializer;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import java.time.OffsetDateTime;
import java.util.Objects;

/** Absolute timeframe. */
@JsonPropertyOrder({
  NotebookAbsoluteTime.JSON_PROPERTY_END,
  NotebookAbsoluteTime.JSON_PROPERTY_LIVE,
  NotebookAbsoluteTime.JSON_PROPERTY_START
})
@jakarta.annotation.Generated(
    value = "https://github.com/DataDog/datadog-api-client-java/blob/master/.generator")
public class NotebookAbsoluteTime {
  @JsonIgnore public boolean unparsed = false;
  public static final String JSON_PROPERTY_END = "end";

  @JsonSerialize(using = JsonTimeSerializer.class)
  private OffsetDateTime end;

  public static final String JSON_PROPERTY_LIVE = "live";
  private Boolean live;

  public static final String JSON_PROPERTY_START = "start";

  @JsonSerialize(using = JsonTimeSerializer.class)
  private OffsetDateTime start;

  public NotebookAbsoluteTime() {}

  @JsonCreator
  public NotebookAbsoluteTime(
      @JsonProperty(required = true, value = JSON_PROPERTY_END) OffsetDateTime end,
      @JsonProperty(required = true, value = JSON_PROPERTY_START) OffsetDateTime start) {
    this.end = end;
    this.start = start;
  }

  public NotebookAbsoluteTime end(OffsetDateTime end) {
    this.end = end;
    return this;
  }

  /**
   * The end time.
   *
   * @return end
   */
  @JsonProperty(JSON_PROPERTY_END)
  @JsonInclude(value = JsonInclude.Include.ALWAYS)
  public OffsetDateTime getEnd() {
    return end;
  }

  public void setEnd(OffsetDateTime end) {
    this.end = end;
  }

  public NotebookAbsoluteTime live(Boolean live) {
    this.live = live;
    return this;
  }

  /**
   * Indicates whether the timeframe should be shifted to end at the current time.
   *
   * @return live
   */
  @jakarta.annotation.Nullable
  @JsonProperty(JSON_PROPERTY_LIVE)
  @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
  public Boolean getLive() {
    return live;
  }

  public void setLive(Boolean live) {
    this.live = live;
  }

  public NotebookAbsoluteTime start(OffsetDateTime start) {
    this.start = start;
    return this;
  }

  /**
   * The start time.
   *
   * @return start
   */
  @JsonProperty(JSON_PROPERTY_START)
  @JsonInclude(value = JsonInclude.Include.ALWAYS)
  public OffsetDateTime getStart() {
    return start;
  }

  public void setStart(OffsetDateTime start) {
    this.start = start;
  }

  /** Return true if this NotebookAbsoluteTime object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    NotebookAbsoluteTime notebookAbsoluteTime = (NotebookAbsoluteTime) o;
    return Objects.equals(this.end, notebookAbsoluteTime.end)
        && Objects.equals(this.live, notebookAbsoluteTime.live)
        && Objects.equals(this.start, notebookAbsoluteTime.start);
  }

  @Override
  public int hashCode() {
    return Objects.hash(end, live, start);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class NotebookAbsoluteTime {\n");
    sb.append("    end: ").append(toIndentedString(end)).append("\n");
    sb.append("    live: ").append(toIndentedString(live)).append("\n");
    sb.append("    start: ").append(toIndentedString(start)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> datadog-api-client-2.24.0-sources.jar: com/datadog/api/client/v1/model/NotebookAbsoluteTime.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.time.OffsetDateTime;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/** Absolute timeframe. */
@JsonPropertyOrder({
  NotebookAbsoluteTime.JSON_PROPERTY_END,
  NotebookAbsoluteTime.JSON_PROPERTY_LIVE,
  NotebookAbsoluteTime.JSON_PROPERTY_START
})
@jakarta.annotation.Generated(
    value = "https://github.com/DataDog/datadog-api-client-java/blob/master/.generator")
public class NotebookAbsoluteTime {
  @JsonIgnore public boolean unparsed = false;
  public static final String JSON_PROPERTY_END = "end";
  private OffsetDateTime end;

  public static final String JSON_PROPERTY_LIVE = "live";
  private Boolean live;

  public static final String JSON_PROPERTY_START = "start";
  private OffsetDateTime start;

  public NotebookAbsoluteTime() {}

  @JsonCreator
  public NotebookAbsoluteTime(
      @JsonProperty(required = true, value = JSON_PROPERTY_END) OffsetDateTime end,
      @JsonProperty(required = true, value = JSON_PROPERTY_START) OffsetDateTime start) {
    this.end = end;
    this.start = start;
  }

  public NotebookAbsoluteTime end(OffsetDateTime end) {
    this.end = end;
    return this;
  }

  /**
   * The end time.
   *
   * @return end
   */
  @JsonProperty(JSON_PROPERTY_END)
  @JsonInclude(value = JsonInclude.Include.ALWAYS)
  public OffsetDateTime getEnd() {
    return end;
  }

  public void setEnd(OffsetDateTime end) {
    this.end = end;
  }

  public NotebookAbsoluteTime live(Boolean live) {
    this.live = live;
    return this;
  }

  /**
   * Indicates whether the timeframe should be shifted to end at the current time.
   *
   * @return live
   */
  @jakarta.annotation.Nullable
  @JsonProperty(JSON_PROPERTY_LIVE)
  @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
  public Boolean getLive() {
    return live;
  }

  public void setLive(Boolean live) {
    this.live = live;
  }

  public NotebookAbsoluteTime start(OffsetDateTime start) {
    this.start = start;
    return this;
  }

  /**
   * The start time.
   *
   * @return start
   */
  @JsonProperty(JSON_PROPERTY_START)
  @JsonInclude(value = JsonInclude.Include.ALWAYS)
  public OffsetDateTime getStart() {
    return start;
  }

  public void setStart(OffsetDateTime start) {
    this.start = start;
  }

  /**
   * A container for additional, undeclared properties. This is a holder for any undeclared
   * properties as specified with the 'additionalProperties' keyword in the OAS document.
   */
  private Map<String, Object> additionalProperties;

  /**
   * Set the additional (undeclared) property with the specified name and value. If the property
   * does not already exist, create it otherwise replace it.
   *
   * @param key The arbitrary key to set
   * @param value The associated value
   * @return NotebookAbsoluteTime
   */
  @JsonAnySetter
  public NotebookAbsoluteTime putAdditionalProperty(String key, Object value) {
    if (this.additionalProperties == null) {
      this.additionalProperties = new HashMap<String, Object>();
    }
    this.additionalProperties.put(key, value);
    return this;
  }

  /**
   * Return the additional (undeclared) property.
   *
   * @return The additional properties
   */
  @JsonAnyGetter
  public Map<String, Object> getAdditionalProperties() {
    return additionalProperties;
  }

  /**
   * Return the additional (undeclared) property with the specified name.
   *
   * @param key The arbitrary key to get
   * @return The specific additional property for the given key
   */
  public Object getAdditionalProperty(String key) {
    if (this.additionalProperties == null) {
      return null;
    }
    return this.additionalProperties.get(key);
  }

  /** Return true if this NotebookAbsoluteTime object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    NotebookAbsoluteTime notebookAbsoluteTime = (NotebookAbsoluteTime) o;
    return Objects.equals(this.end, notebookAbsoluteTime.end)
        && Objects.equals(this.live, notebookAbsoluteTime.live)
        && Objects.equals(this.start, notebookAbsoluteTime.start)
        && Objects.equals(this.additionalProperties, notebookAbsoluteTime.additionalProperties);
  }

  @Override
  public int hashCode() {
    return Objects.hash(end, live, start, additionalProperties);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class NotebookAbsoluteTime {\n");
    sb.append("    end: ").append(toIndentedString(end)).append("\n");
    sb.append("    live: ").append(toIndentedString(live)).append("\n");
    sb.append("    start: ").append(toIndentedString(start)).append("\n");
    sb.append("    additionalProperties: ")
        .append(toIndentedString(additionalProperties))
        .append("\n");
    sb.append('}');
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
